@@ -25,8 +25,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
 extern "C" {
-#include <jpeglib.h>
+#include <jpeglib.h> // Must be included before transupp.h
+
 #include "transupp.h"
 }
 
@@ -44,16 +46,15 @@ extern "C" {
 #include <exiv2/exiv2.hpp>
 
 // Local
-#include "gwenview_lib_debug.h"
-#include "jpegerrormanager.h"
-#include "iodevicejpegsourcemanager.h"
 #include "exiv2imageloader.h"
+#include "gwenview_lib_debug.h"
 #include "gwenviewconfig.h"
 #include "imageutils.h"
+#include "iodevicejpegsourcemanager.h"
+#include "jpegerrormanager.h"
 
 namespace Gwenview
 {
-
 const int INMEM_DST_DELTA = 4096;
 
 //-----------------------------------------------
@@ -61,9 +62,8 @@ const int INMEM_DST_DELTA = 4096;
 // In-memory data destination manager for libjpeg
 //
 //-----------------------------------------------
-struct inmem_dest_mgr : public jpeg_destination_mgr
-{
-    QByteArray* mOutput;
+struct inmem_dest_mgr : public jpeg_destination_mgr {
+    QByteArray *mOutput;
 
     void dump()
     {
@@ -76,19 +76,19 @@ struct inmem_dest_mgr : public jpeg_destination_mgr
 
 void inmem_init_destination(j_compress_ptr cinfo)
 {
-    auto* dest = (inmem_dest_mgr*)(cinfo->dest);
+    auto *dest = (inmem_dest_mgr *)(cinfo->dest);
     if (dest->mOutput->size() == 0) {
         dest->mOutput->resize(INMEM_DST_DELTA);
     }
     dest->free_in_buffer = dest->mOutput->size();
-    dest->next_output_byte = (JOCTET*)(dest->mOutput->data());
+    dest->next_output_byte = (JOCTET *)(dest->mOutput->data());
 }
 
 boolean inmem_empty_output_buffer(j_compress_ptr cinfo)
 {
-    auto* dest = (inmem_dest_mgr*)(cinfo->dest);
+    auto *dest = (inmem_dest_mgr *)(cinfo->dest);
     dest->mOutput->resize(dest->mOutput->size() + INMEM_DST_DELTA);
-    dest->next_output_byte = (JOCTET*)(dest->mOutput->data() + dest->mOutput->size() - INMEM_DST_DELTA);
+    dest->next_output_byte = (JOCTET *)(dest->mOutput->data() + dest->mOutput->size() - INMEM_DST_DELTA);
     dest->free_in_buffer = INMEM_DST_DELTA;
 
     return true;
@@ -96,8 +96,8 @@ boolean inmem_empty_output_buffer(j_compress_ptr cinfo)
 
 void inmem_term_destination(j_compress_ptr cinfo)
 {
-    auto* dest = (inmem_dest_mgr*)(cinfo->dest);
-    int finalSize = dest->next_output_byte - (JOCTET*)(dest->mOutput->data());
+    auto *dest = (inmem_dest_mgr *)(cinfo->dest);
+    int finalSize = dest->next_output_byte - (JOCTET *)(dest->mOutput->data());
     Q_ASSERT(finalSize >= 0);
     dest->mOutput->resize(finalSize);
 }
@@ -107,8 +107,7 @@ void inmem_term_destination(j_compress_ptr cinfo)
 // JpegContent::Private
 //
 //---------------------
-struct JpegContent::Private
-{
+struct JpegContent::Private {
     // JpegContent usually stores the image pixels as compressed JPEG data in
     // mRawData. However if the image is set with setImage() because the user
     // performed a lossy image manipulation, mRawData is cleared and the image
@@ -133,13 +132,11 @@ struct JpegContent::Private
         mPendingTransformation = false;
     }
 
-    void setupInmemDestination(j_compress_ptr cinfo, QByteArray* outputData)
+    void setupInmemDestination(j_compress_ptr cinfo, QByteArray *outputData)
     {
         Q_ASSERT(!cinfo->dest);
-        auto* dest = (inmem_dest_mgr*)
-                               (*cinfo->mem->alloc_small)((j_common_ptr) cinfo, JPOOL_PERMANENT,
-                                       sizeof(inmem_dest_mgr));
-        cinfo->dest = (struct jpeg_destination_mgr*)(dest);
+        auto *dest = (inmem_dest_mgr *)(*cinfo->mem->alloc_small)((j_common_ptr)cinfo, JPOOL_PERMANENT, sizeof(inmem_dest_mgr));
+        cinfo->dest = (struct jpeg_destination_mgr *)(dest);
 
         dest->init_destination = inmem_init_destination;
         dest->empty_output_buffer = inmem_empty_output_buffer;
@@ -211,10 +208,10 @@ JpegContent::~JpegContent()
     delete d;
 }
 
-bool JpegContent::load(const QString& path)
+bool JpegContent::load(const QString &path)
 {
     if (d->mFile.isOpen()) {
-        d->mFile.unmap(reinterpret_cast<unsigned char*>(d->mRawData.data()));
+        d->mFile.unmap(reinterpret_cast<unsigned char *>(d->mRawData.data()));
         d->mFile.close();
         d->mRawData.clear();
     }
@@ -226,7 +223,7 @@ bool JpegContent::load(const QString& path)
     }
 
     QByteArray rawData;
-    uchar* mappedFile = d->mFile.map(0, d->mFile.size(), QFileDevice::MapPrivateOption);
+    uchar *mappedFile = d->mFile.map(0, d->mFile.size(), QFileDevice::MapPrivateOption);
     if (mappedFile == nullptr) {
         // process' mapping limit exceeded, file is sealed or filesystem doesn't support it, etc.
         qCDebug(GWENVIEW_LIB_LOG) << "Could not mmap '" << path << "', falling back to QFile::readAll()\n";
@@ -235,13 +232,13 @@ bool JpegContent::load(const QString& path)
         // all read in, no need to keep it open
         d->mFile.close();
     } else {
-        rawData = QByteArray::fromRawData(reinterpret_cast<char*>(mappedFile), d->mFile.size());
+        rawData = QByteArray::fromRawData(reinterpret_cast<char *>(mappedFile), d->mFile.size());
     }
 
     return loadFromData(rawData);
 }
 
-bool JpegContent::loadFromData(const QByteArray& data)
+bool JpegContent::loadFromData(const QByteArray &data)
 {
     std::unique_ptr<Exiv2::Image> image;
     Exiv2ImageLoader loader;
@@ -253,7 +250,7 @@ bool JpegContent::loadFromData(const QByteArray& data)
     return loadFromData(data, image.get());
 }
 
-bool JpegContent::loadFromData(const QByteArray& data, Exiv2::Image* exiv2Image)
+bool JpegContent::loadFromData(const QByteArray &data, Exiv2::Image *exiv2Image)
 {
     d->mPendingTransformation = false;
     d->mTransformMatrix.reset();
@@ -264,7 +261,8 @@ bool JpegContent::loadFromData(const QByteArray& data, Exiv2::Image* exiv2Image)
         return false;
     }
 
-    if (!d->readSize()) return false;
+    if (!d->readSize())
+        return false;
 
     d->mExifData = exiv2Image->exifData();
     d->mComment = QString::fromUtf8(exiv2Image->comment().c_str());
@@ -316,7 +314,7 @@ int JpegContent::dotsPerMeterY() const
     return dotsPerMeter(QStringLiteral("YResolution"));
 }
 
-int JpegContent::dotsPerMeter(const QString& keyName) const
+int JpegContent::dotsPerMeter(const QString &keyName) const
 {
     Exiv2::ExifKey keyResUnit("Exif.Image.ResolutionUnit");
     auto it = d->mExifData.findKey(keyResUnit);
@@ -338,9 +336,9 @@ int JpegContent::dotsPerMeter(const QString& keyName) const
     //         Other = reserved
     const float INCHESPERMETER = (100. / 2.54);
     switch (res) {
-    case 3:  // dots per cm
+    case 3: // dots per cm
         return int(it->toLong() * 100);
-    default:  // dots per inch
+    default: // dots per inch
         return int(it->toLong() * INCHESPERMETER);
     }
 
@@ -368,7 +366,7 @@ QString JpegContent::comment() const
     return d->mComment;
 }
 
-void JpegContent::setComment(const QString& comment)
+void JpegContent::setComment(const QString &comment)
 {
     d->mComment = comment;
 }
@@ -387,16 +385,19 @@ static QTransform createScaleMatrix(int dx, int dy)
     return matrix;
 }
 
-struct OrientationInfo
-{
+struct OrientationInfo {
     OrientationInfo()
-    : orientation(NOT_AVAILABLE)
-    , jxform(JXFORM_NONE)
-    {}
+        : orientation(NOT_AVAILABLE)
+        , jxform(JXFORM_NONE)
+    {
+    }
 
     OrientationInfo(Orientation o, const QTransform &m, JXFORM_CODE j)
-    : orientation(o), matrix(m), jxform(j)
-    {}
+        : orientation(o)
+        , matrix(m)
+        , jxform(j)
+    {
+    }
 
     Orientation orientation;
     QTransform matrix;
@@ -404,7 +405,7 @@ struct OrientationInfo
 };
 using OrientationInfoList = QList<OrientationInfo>;
 
-static const OrientationInfoList& orientationInfoList()
+static const OrientationInfoList &orientationInfoList()
 {
     static OrientationInfoList list;
     if (list.size() == 0) {
@@ -412,17 +413,10 @@ static const OrientationInfoList& orientationInfoList()
         QTransform hflip = createScaleMatrix(-1, 1);
         QTransform vflip = createScaleMatrix(1, -1);
 
-        list
-                << OrientationInfo()
-                << OrientationInfo(NORMAL, QTransform(), JXFORM_NONE)
-                << OrientationInfo(HFLIP, hflip, JXFORM_FLIP_H)
-                << OrientationInfo(ROT_180, createRotMatrix(180), JXFORM_ROT_180)
-                << OrientationInfo(VFLIP, vflip, JXFORM_FLIP_V)
-                << OrientationInfo(TRANSPOSE, hflip * rot90, JXFORM_TRANSPOSE)
-                << OrientationInfo(ROT_90, rot90, JXFORM_ROT_90)
-                << OrientationInfo(TRANSVERSE, vflip * rot90, JXFORM_TRANSVERSE)
-                << OrientationInfo(ROT_270, createRotMatrix(270), JXFORM_ROT_270)
-                ;
+        list << OrientationInfo() << OrientationInfo(NORMAL, QTransform(), JXFORM_NONE) << OrientationInfo(HFLIP, hflip, JXFORM_FLIP_H)
+             << OrientationInfo(ROT_180, createRotMatrix(180), JXFORM_ROT_180) << OrientationInfo(VFLIP, vflip, JXFORM_FLIP_V)
+             << OrientationInfo(TRANSPOSE, hflip * rot90, JXFORM_TRANSPOSE) << OrientationInfo(ROT_90, rot90, JXFORM_ROT_90)
+             << OrientationInfo(TRANSVERSE, vflip * rot90, JXFORM_TRANSVERSE) << OrientationInfo(ROT_270, createRotMatrix(270), JXFORM_ROT_270);
     }
     return list;
 }
@@ -453,17 +447,13 @@ static void dumpMatrix(const QTransform& matrix)
 }
 #endif
 
-static bool matricesAreSame(const QTransform& m1, const QTransform& m2, double tolerance)
+static bool matricesAreSame(const QTransform &m1, const QTransform &m2, double tolerance)
 {
-    return fabs(m1.m11() - m2.m11()) < tolerance
-           && fabs(m1.m12() - m2.m12()) < tolerance
-           && fabs(m1.m21() - m2.m21()) < tolerance
-           && fabs(m1.m22() - m2.m22()) < tolerance
-           && fabs(m1.dx()  - m2.dx()) < tolerance
-           && fabs(m1.dy()  - m2.dy()) < tolerance;
+    return fabs(m1.m11() - m2.m11()) < tolerance && fabs(m1.m12() - m2.m12()) < tolerance && fabs(m1.m21() - m2.m21()) < tolerance
+        && fabs(m1.m22() - m2.m22()) < tolerance && fabs(m1.dx() - m2.dx()) < tolerance && fabs(m1.dy() - m2.dy()) < tolerance;
 }
 
-static JXFORM_CODE findJxform(const QTransform& matrix)
+static JXFORM_CODE findJxform(const QTransform &matrix)
 {
     OrientationInfoList::ConstIterator it(orientationInfoList().begin()), end(orientationInfoList().end());
     for (; it != end; ++it) {
@@ -487,8 +477,8 @@ void JpegContent::applyPendingTransformation()
     // Init JPEG structs
     struct jpeg_decompress_struct srcinfo;
     struct jpeg_compress_struct dstinfo;
-    jvirt_barray_ptr * src_coef_arrays;
-    jvirt_barray_ptr * dst_coef_arrays;
+    jvirt_barray_ptr *src_coef_arrays;
+    jvirt_barray_ptr *dst_coef_arrays;
 
     // Initialize the JPEG decompression object
     JPEGErrorManager srcErrorManager;
@@ -516,7 +506,7 @@ void JpegContent::applyPendingTransformation()
     // Enable saving of extra markers that we want to copy
     jcopy_markers_setup(&srcinfo, JCOPYOPT_ALL);
 
-    (void) jpeg_read_header(&srcinfo, true);
+    (void)jpeg_read_header(&srcinfo, true);
 
     // Init transformation
     jpeg_transform_info transformoption;
@@ -531,11 +521,9 @@ void JpegContent::applyPendingTransformation()
     jpeg_copy_critical_parameters(&srcinfo, &dstinfo);
 
     /* Adjust destination parameters if required by transform options;
-    * also find out which set of coefficient arrays will hold the output.
-    */
-    dst_coef_arrays = jtransform_adjust_parameters(&srcinfo, &dstinfo,
-                      src_coef_arrays,
-                      &transformoption);
+     * also find out which set of coefficient arrays will hold the output.
+     */
+    dst_coef_arrays = jtransform_adjust_parameters(&srcinfo, &dstinfo, src_coef_arrays, &transformoption);
 
     /* Specify data destination for compression */
     QByteArray output;
@@ -549,14 +537,12 @@ void JpegContent::applyPendingTransformation()
     jcopy_markers_execute(&srcinfo, &dstinfo, JCOPYOPT_ALL);
 
     /* Execute image transformation, if any */
-    jtransform_execute_transformation(&srcinfo, &dstinfo,
-                                      src_coef_arrays,
-                                      &transformoption);
+    jtransform_execute_transformation(&srcinfo, &dstinfo, src_coef_arrays, &transformoption);
 
     /* Finish compression and release memory */
     jpeg_finish_compress(&dstinfo);
     jpeg_destroy_compress(&dstinfo);
-    (void) jpeg_finish_decompress(&srcinfo);
+    (void)jpeg_finish_decompress(&srcinfo);
     jpeg_destroy_decompress(&srcinfo);
 
     // Set rawData to our new JPEG
@@ -567,7 +553,7 @@ QImage JpegContent::thumbnail() const
 {
     QImage image;
     if (!d->mExifData.empty()) {
-#if(EXIV2_TEST_VERSION(0,17,91))
+#if (EXIV2_TEST_VERSION(0, 17, 91))
         Exiv2::ExifThumbC thumb(d->mExifData);
         Exiv2::DataBuf thumbnail = thumb.copy();
 #else
@@ -581,14 +567,14 @@ QImage JpegContent::thumbnail() const
             QRect validArea(QPoint(it->toLong(0), it->toLong(2)), QPoint(it->toLong(1), it->toLong(3)));
             image = image.copy(validArea);
         } else {
-            // Unfortunately, Sony does not provide an exif tag that specifies the valid area of the 
+            // Unfortunately, Sony does not provide an exif tag that specifies the valid area of the
             // embedded thumbnail. Need to derive it from the size of the preview image instead.
             it = d->mExifData.findKey(Exiv2::ExifKey("Exif.Sony1.PreviewImageSize"));
             if (it != d->mExifData.end() && it->count() == 2) {
                 const long prevHeight = it->toLong(0);
                 const long prevWidth = it->toLong(1);
 
-                if (image.width() > 0 && prevWidth > 0 ) {
+                if (image.width() > 0 && prevWidth > 0) {
                     const double scale = prevWidth / image.width();
 
                     // the embedded thumb only needs to be cropped vertically
@@ -611,7 +597,7 @@ QImage JpegContent::thumbnail() const
     return image;
 }
 
-void JpegContent::setThumbnail(const QImage& thumbnail)
+void JpegContent::setThumbnail(const QImage &thumbnail)
 {
     if (d->mExifData.empty()) {
         return;
@@ -626,21 +612,21 @@ void JpegContent::setThumbnail(const QImage& thumbnail)
         return;
     }
 
-#if (EXIV2_TEST_VERSION(0,17,91))
+#if (EXIV2_TEST_VERSION(0, 17, 91))
     Exiv2::ExifThumb thumb(d->mExifData);
-    thumb.setJpegThumbnail((unsigned char*)array.data(), array.size());
+    thumb.setJpegThumbnail((unsigned char *)array.data(), array.size());
 #else
-    d->mExifData.setJpegThumbnail((unsigned char*)array.data(), array.size());
+    d->mExifData.setJpegThumbnail((unsigned char *)array.data(), array.size());
 #endif
 }
 
-bool JpegContent::save(const QString& path)
+bool JpegContent::save(const QString &path)
 {
     // we need to take ownership of the input file's data
     // if the input file is still open, data is still only mem-mapped
     if (d->mFile.isOpen()) {
         // backup the mmap() pointer
-        auto* mappedFile = reinterpret_cast<unsigned char*>(d->mRawData.data());
+        auto *mappedFile = reinterpret_cast<unsigned char *>(d->mRawData.data());
         // read the file to memory
         d->mRawData = d->mFile.readAll();
         d->mFile.unmap(mappedFile);
@@ -656,7 +642,7 @@ bool JpegContent::save(const QString& path)
     return save(&file);
 }
 
-bool JpegContent::save(QIODevice* device)
+bool JpegContent::save(QIODevice *device)
 {
     if (!d->mImage.isNull()) {
         if (!d->updateRawDataFromImage()) {
@@ -675,7 +661,7 @@ bool JpegContent::save(QIODevice* device)
     }
 
     std::unique_ptr<Exiv2::Image> image;
-    image.reset(Exiv2::ImageFactory::open((unsigned char*)d->mRawData.data(), d->mRawData.size()).release());
+    image.reset(Exiv2::ImageFactory::open((unsigned char *)d->mRawData.data(), d->mRawData.size()).release());
 
     // Store Exif info
     image->setExifData(d->mExifData);
@@ -683,9 +669,9 @@ bool JpegContent::save(QIODevice* device)
     image->writeMetadata();
 
     // Update mRawData
-    Exiv2::BasicIo& io = image->io();
+    Exiv2::BasicIo &io = image->io();
     d->mRawData.resize(io.size());
-    io.read((unsigned char*)d->mRawData.data(), io.size());
+    io.read((unsigned char *)d->mRawData.data(), io.size());
 
     QDataStream stream(device);
     stream.writeRawData(d->mRawData.data(), d->mRawData.size());
@@ -700,7 +686,7 @@ QString JpegContent::errorString() const
     return d->mErrorString;
 }
 
-void JpegContent::setImage(const QImage& image)
+void JpegContent::setImage(const QImage &image)
 {
     d->mRawData.clear();
     d->mImage = image;
